@@ -1,13 +1,9 @@
 require "action_view"
 require "action_view/template"
-require "redcarpet"
+require "markerb/markdown"
 require "markerb/railtie"
 
 module Markerb
-  mattr_accessor :processing_options, :renderer
-  @@processing_options = {}
-  @@renderer = Redcarpet::Render::HTML
-
   class Handler
     def erb_handler
       @erb_handler ||= ActionView::Template.registered_template_handler(:erb)
@@ -16,7 +12,7 @@ module Markerb
     def call(template)
       compiled_source = erb_handler.call(template)
       if template.formats.include?(:html)
-        "Redcarpet::Markdown.new(Markerb.renderer, Markerb.processing_options).render(begin;#{compiled_source};end).html_safe"
+        "Markerb::Markdown.to_html(begin;#{compiled_source};end).html_safe"
       else
         compiled_source
       end
